==> openshift-hive-operator-container-v2.0.1-1.tar.gz: github.com/heptio/velero@v1.0.0/site/docs/v0.4.0/cli-reference/ark_restore_get.md <==
## ark restore get

get restores

### Synopsis


get restores

```
ark restore get [flags]
```

### Options

```
  -h, --help                        help for get
      --label-columns stringArray   a comma-separated list of labels to be displayed as columns
  -o, --output string               Output display format. For create commands, display the object but do not send it to the server. Valid formats are 'table', 'json', and 'yaml'. (default "table")
  -l, --selector string             only show items matching this label selector
      --show-labels                 show labels in the last column
```

### Options inherited from parent commands

```
      --alsologtostderr                  log to standard error as well as files
      --kubeconfig string                Path to the kubeconfig file to use to talk to the Kubernetes apiserver. If unset, try the environment variable KUBECONFIG, as well as in-cluster configuration
      --log_backtrace_at traceLocation   when logging hits line file:N, emit a stack trace (default :0)
      --log_dir string                   If non-empty, write log files in this directory
      --logtostderr                      log to standard error instead of files
      --stderrthreshold severity         logs at or above this threshold go to stderr (default 2)
  -v, --v Level                          log level for V logs
      --vmodule moduleSpec               comma-separated list of pattern=N settings for file-filtered logging
```

### SEE ALSO
* [ark restore](ark_restore.md)	 - Work with restores

==> openshift-hive-operator-container-v2.1.12-3.tar.gz: github.com/heptio/velero@v1.0.0/site/docs/v0.7.1/cli-reference/ark_restore_get.md <==
## ark restore get

Get restores

### Synopsis


Get restores

```
ark restore get [flags]
```

### Options

```
  -h, --help                        help for get
      --label-columns stringArray   a comma-separated list of labels to be displayed as columns
  -o, --output string               Output display format. For create commands, display the object but do not send it to the server. Valid formats are 'table', 'json', and 'yaml'. (default "table")
  -l, --selector string             only show items matching this label selector
      --show-labels                 show labels in the last column
```

### Options inherited from parent commands

```
      --alsologtostderr                  log to standard error as well as files
      --kubeconfig string                Path to the kubeconfig file to use to talk to the Kubernetes apiserver. If unset, try the environment variable KUBECONFIG, as well as in-cluster configuration
      --log_backtrace_at traceLocation   when logging hits line file:N, emit a stack trace (default :0)
      --log_dir string                   If non-empty, write log files in this directory
      --logtostderr                      log to standard error instead of files
  -n, --namespace string                 The namespace in which Ark should operate (default "heptio-ark")
      --stderrthreshold severity         logs at or above this threshold go to stderr (default 2)
  -v, --v Level                          log level for V logs
      --vmodule moduleSpec               comma-separated list of pattern=N settings for file-filtered logging
```

### SEE ALSO
* [ark restore](ark_restore.md)	 - Work with restores
